```
Usage: vcd catalog acl share [OPTIONS] <catalog-name>

Options:
  --access-level <access-level>  access level at which the catalog is shared.
                                 ReadOnly by default
  -h, --help                     Show this message and exit.

```
